# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1VariableReference(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source': 'str',
        'source_argument': 'V1VariableRefArgument',
        'source_constant': 'V1VariableRefConstant',
        'source_step': 'V1VariableRefStep'
    }

    attribute_map = {
        'source': 'source',
        'source_argument': 'source_argument',
        'source_constant': 'source_constant',
        'source_step': 'source_step'
    }

    def __init__(self, source=None, source_argument=None, source_constant=None, source_step=None, local_vars_configuration=None):  # noqa: E501
        """V1VariableReference - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._source = None
        self._source_argument = None
        self._source_constant = None
        self._source_step = None
        self.discriminator = None

        self.source = source
        if source_argument is not None:
            self.source_argument = source_argument
        if source_constant is not None:
            self.source_constant = source_constant
        if source_step is not None:
            self.source_step = source_step

    @property
    def source(self):
        """Gets the source of this V1VariableReference.  # noqa: E501


        :return: The source of this V1VariableReference.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this V1VariableReference.


        :param source: The source of this V1VariableReference.  # noqa: E501
        :type source: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["argument", "step", "constant"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def source_argument(self):
        """Gets the source_argument of this V1VariableReference.  # noqa: E501


        :return: The source_argument of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefArgument
        """
        return self._source_argument

    @source_argument.setter
    def source_argument(self, source_argument):
        """Sets the source_argument of this V1VariableReference.


        :param source_argument: The source_argument of this V1VariableReference.  # noqa: E501
        :type source_argument: V1VariableRefArgument
        """

        self._source_argument = source_argument

    @property
    def source_constant(self):
        """Gets the source_constant of this V1VariableReference.  # noqa: E501


        :return: The source_constant of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefConstant
        """
        return self._source_constant

    @source_constant.setter
    def source_constant(self, source_constant):
        """Sets the source_constant of this V1VariableReference.


        :param source_constant: The source_constant of this V1VariableReference.  # noqa: E501
        :type source_constant: V1VariableRefConstant
        """

        self._source_constant = source_constant

    @property
    def source_step(self):
        """Gets the source_step of this V1VariableReference.  # noqa: E501


        :return: The source_step of this V1VariableReference.  # noqa: E501
        :rtype: V1VariableRefStep
        """
        return self._source_step

    @source_step.setter
    def source_step(self, source_step):
        """Sets the source_step of this V1VariableReference.


        :param source_step: The source_step of this V1VariableReference.  # noqa: E501
        :type source_step: V1VariableRefStep
        """

        self._source_step = source_step

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1VariableReference):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1VariableReference):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseRunExecution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'arguments': 'V1RunArgument',
        'artifacts': 'dict[str, ResponseActualArtifacts]',
        'create_dt': 'datetime',
        'id': 'int',
        'pipeline_step_execution': 'ResponseReducedPipelineStepExecution',
        'run_spec': 'ResponseRunSpec',
        'status': 'str',
        'status_last_updated': 'datetime',
        'volume_info_list': 'list[ResponseVolumeInfo]',
        'workload': 'ResponseWorkloadInfo'
    }

    attribute_map = {
        'arguments': 'arguments',
        'artifacts': 'artifacts',
        'create_dt': 'create_dt',
        'id': 'id',
        'pipeline_step_execution': 'pipeline_step_execution',
        'run_spec': 'run_spec',
        'status': 'status',
        'status_last_updated': 'status_last_updated',
        'volume_info_list': 'volume_info_list',
        'workload': 'workload'
    }

    def __init__(self, arguments=None, artifacts=None, create_dt=None, id=None, pipeline_step_execution=None, run_spec=None, status=None, status_last_updated=None, volume_info_list=None, workload=None, local_vars_configuration=None):  # noqa: E501
        """ResponseRunExecution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._arguments = None
        self._artifacts = None
        self._create_dt = None
        self._id = None
        self._pipeline_step_execution = None
        self._run_spec = None
        self._status = None
        self._status_last_updated = None
        self._volume_info_list = None
        self._workload = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if artifacts is not None:
            self.artifacts = artifacts
        if create_dt is not None:
            self.create_dt = create_dt
        if id is not None:
            self.id = id
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        if run_spec is not None:
            self.run_spec = run_spec
        if status is not None:
            self.status = status
        if status_last_updated is not None:
            self.status_last_updated = status_last_updated
        if volume_info_list is not None:
            self.volume_info_list = volume_info_list
        if workload is not None:
            self.workload = workload

    @property
    def arguments(self):
        """Gets the arguments of this ResponseRunExecution.  # noqa: E501


        :return: The arguments of this ResponseRunExecution.  # noqa: E501
        :rtype: V1RunArgument
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this ResponseRunExecution.


        :param arguments: The arguments of this ResponseRunExecution.  # noqa: E501
        :type arguments: V1RunArgument
        """

        self._arguments = arguments

    @property
    def artifacts(self):
        """Gets the artifacts of this ResponseRunExecution.  # noqa: E501


        :return: The artifacts of this ResponseRunExecution.  # noqa: E501
        :rtype: dict[str, ResponseActualArtifacts]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this ResponseRunExecution.


        :param artifacts: The artifacts of this ResponseRunExecution.  # noqa: E501
        :type artifacts: dict[str, ResponseActualArtifacts]
        """

        self._artifacts = artifacts

    @property
    def create_dt(self):
        """Gets the create_dt of this ResponseRunExecution.  # noqa: E501


        :return: The create_dt of this ResponseRunExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._create_dt

    @create_dt.setter
    def create_dt(self, create_dt):
        """Sets the create_dt of this ResponseRunExecution.


        :param create_dt: The create_dt of this ResponseRunExecution.  # noqa: E501
        :type create_dt: datetime
        """

        self._create_dt = create_dt

    @property
    def id(self):
        """Gets the id of this ResponseRunExecution.  # noqa: E501


        :return: The id of this ResponseRunExecution.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ResponseRunExecution.


        :param id: The id of this ResponseRunExecution.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this ResponseRunExecution.  # noqa: E501


        :return: The pipeline_step_execution of this ResponseRunExecution.  # noqa: E501
        :rtype: ResponseReducedPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this ResponseRunExecution.


        :param pipeline_step_execution: The pipeline_step_execution of this ResponseRunExecution.  # noqa: E501
        :type pipeline_step_execution: ResponseReducedPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def run_spec(self):
        """Gets the run_spec of this ResponseRunExecution.  # noqa: E501


        :return: The run_spec of this ResponseRunExecution.  # noqa: E501
        :rtype: ResponseRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this ResponseRunExecution.


        :param run_spec: The run_spec of this ResponseRunExecution.  # noqa: E501
        :type run_spec: ResponseRunSpec
        """

        self._run_spec = run_spec

    @property
    def status(self):
        """Gets the status of this ResponseRunExecution.  # noqa: E501


        :return: The status of this ResponseRunExecution.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseRunExecution.


        :param status: The status of this ResponseRunExecution.  # noqa: E501
        :type status: str
        """
        allowed_values = ["queued", "pending", "running", "failed", "completed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def status_last_updated(self):
        """Gets the status_last_updated of this ResponseRunExecution.  # noqa: E501


        :return: The status_last_updated of this ResponseRunExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._status_last_updated

    @status_last_updated.setter
    def status_last_updated(self, status_last_updated):
        """Sets the status_last_updated of this ResponseRunExecution.


        :param status_last_updated: The status_last_updated of this ResponseRunExecution.  # noqa: E501
        :type status_last_updated: datetime
        """

        self._status_last_updated = status_last_updated

    @property
    def volume_info_list(self):
        """Gets the volume_info_list of this ResponseRunExecution.  # noqa: E501


        :return: The volume_info_list of this ResponseRunExecution.  # noqa: E501
        :rtype: list[ResponseVolumeInfo]
        """
        return self._volume_info_list

    @volume_info_list.setter
    def volume_info_list(self, volume_info_list):
        """Sets the volume_info_list of this ResponseRunExecution.


        :param volume_info_list: The volume_info_list of this ResponseRunExecution.  # noqa: E501
        :type volume_info_list: list[ResponseVolumeInfo]
        """

        self._volume_info_list = volume_info_list

    @property
    def workload(self):
        """Gets the workload of this ResponseRunExecution.  # noqa: E501


        :return: The workload of this ResponseRunExecution.  # noqa: E501
        :rtype: ResponseWorkloadInfo
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this ResponseRunExecution.


        :param workload: The workload of this ResponseRunExecution.  # noqa: E501
        :type workload: ResponseWorkloadInfo
        """

        self._workload = workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseRunExecution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseRunExecution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1Execution(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'arguments': 'dict[str, str]',
        'execution_number': 'int',
        'organization_name': 'str',
        'pipeline_name': 'str',
        'project_name': 'str'
    }

    attribute_map = {
        'arguments': 'arguments',
        'execution_number': 'execution_number',
        'organization_name': 'organization_name',
        'pipeline_name': 'pipeline_name',
        'project_name': 'project_name'
    }

    def __init__(self, arguments=None, execution_number=None, organization_name=None, pipeline_name=None, project_name=None, local_vars_configuration=None):  # noqa: E501
        """V1Execution - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._arguments = None
        self._execution_number = None
        self._organization_name = None
        self._pipeline_name = None
        self._project_name = None
        self.discriminator = None

        self.arguments = arguments
        self.execution_number = execution_number
        self.organization_name = organization_name
        self.pipeline_name = pipeline_name
        self.project_name = project_name

    @property
    def arguments(self):
        """Gets the arguments of this V1Execution.  # noqa: E501


        :return: The arguments of this V1Execution.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this V1Execution.


        :param arguments: The arguments of this V1Execution.  # noqa: E501
        :type arguments: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and arguments is None:  # noqa: E501
            raise ValueError("Invalid value for `arguments`, must not be `None`")  # noqa: E501

        self._arguments = arguments

    @property
    def execution_number(self):
        """Gets the execution_number of this V1Execution.  # noqa: E501


        :return: The execution_number of this V1Execution.  # noqa: E501
        :rtype: int
        """
        return self._execution_number

    @execution_number.setter
    def execution_number(self, execution_number):
        """Sets the execution_number of this V1Execution.


        :param execution_number: The execution_number of this V1Execution.  # noqa: E501
        :type execution_number: int
        """
        if self.local_vars_configuration.client_side_validation and execution_number is None:  # noqa: E501
            raise ValueError("Invalid value for `execution_number`, must not be `None`")  # noqa: E501

        self._execution_number = execution_number

    @property
    def organization_name(self):
        """Gets the organization_name of this V1Execution.  # noqa: E501


        :return: The organization_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._organization_name

    @organization_name.setter
    def organization_name(self, organization_name):
        """Sets the organization_name of this V1Execution.


        :param organization_name: The organization_name of this V1Execution.  # noqa: E501
        :type organization_name: str
        """
        if self.local_vars_configuration.client_side_validation and organization_name is None:  # noqa: E501
            raise ValueError("Invalid value for `organization_name`, must not be `None`")  # noqa: E501

        self._organization_name = organization_name

    @property
    def pipeline_name(self):
        """Gets the pipeline_name of this V1Execution.  # noqa: E501


        :return: The pipeline_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_name

    @pipeline_name.setter
    def pipeline_name(self, pipeline_name):
        """Sets the pipeline_name of this V1Execution.


        :param pipeline_name: The pipeline_name of this V1Execution.  # noqa: E501
        :type pipeline_name: str
        """
        if self.local_vars_configuration.client_side_validation and pipeline_name is None:  # noqa: E501
            raise ValueError("Invalid value for `pipeline_name`, must not be `None`")  # noqa: E501

        self._pipeline_name = pipeline_name

    @property
    def project_name(self):
        """Gets the project_name of this V1Execution.  # noqa: E501


        :return: The project_name of this V1Execution.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this V1Execution.


        :param project_name: The project_name of this V1Execution.  # noqa: E501
        :type project_name: str
        """
        if self.local_vars_configuration.client_side_validation and project_name is None:  # noqa: E501
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Execution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Execution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmRunExecutionEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'OrmAccessToken',
        'pipeline_step_execution': 'OrmPipelineStepExecution',
        'run': 'OrmRun',
        'run_spec': 'OrmRunSpec',
        'volume': 'list[OrmVolume]',
        'workload': 'OrmWorkload'
    }

    attribute_map = {
        'access_token': 'access_token',
        'pipeline_step_execution': 'pipeline_step_execution',
        'run': 'run',
        'run_spec': 'run_spec',
        'volume': 'volume',
        'workload': 'workload'
    }

    def __init__(self, access_token=None, pipeline_step_execution=None, run=None, run_spec=None, volume=None, workload=None, local_vars_configuration=None):  # noqa: E501
        """OrmRunExecutionEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._pipeline_step_execution = None
        self._run = None
        self._run_spec = None
        self._volume = None
        self._workload = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        if run is not None:
            self.run = run
        if run_spec is not None:
            self.run_spec = run_spec
        if volume is not None:
            self.volume = volume
        if workload is not None:
            self.workload = workload

    @property
    def access_token(self):
        """Gets the access_token of this OrmRunExecutionEdges.  # noqa: E501


        :return: The access_token of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmAccessToken
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this OrmRunExecutionEdges.


        :param access_token: The access_token of this OrmRunExecutionEdges.  # noqa: E501
        :type access_token: OrmAccessToken
        """

        self._access_token = access_token

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501


        :return: The pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this OrmRunExecutionEdges.


        :param pipeline_step_execution: The pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501
        :type pipeline_step_execution: OrmPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def run(self):
        """Gets the run of this OrmRunExecutionEdges.  # noqa: E501


        :return: The run of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmRun
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this OrmRunExecutionEdges.


        :param run: The run of this OrmRunExecutionEdges.  # noqa: E501
        :type run: OrmRun
        """

        self._run = run

    @property
    def run_spec(self):
        """Gets the run_spec of this OrmRunExecutionEdges.  # noqa: E501


        :return: The run_spec of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this OrmRunExecutionEdges.


        :param run_spec: The run_spec of this OrmRunExecutionEdges.  # noqa: E501
        :type run_spec: OrmRunSpec
        """

        self._run_spec = run_spec

    @property
    def volume(self):
        """Gets the volume of this OrmRunExecutionEdges.  # noqa: E501


        :return: The volume of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: list[OrmVolume]
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this OrmRunExecutionEdges.


        :param volume: The volume of this OrmRunExecutionEdges.  # noqa: E501
        :type volume: list[OrmVolume]
        """

        self._volume = volume

    @property
    def workload(self):
        """Gets the workload of this OrmRunExecutionEdges.  # noqa: E501


        :return: The workload of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmWorkload
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this OrmRunExecutionEdges.


        :param workload: The workload of this OrmRunExecutionEdges.  # noqa: E501
        :type workload: OrmWorkload
        """

        self._workload = workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmRunExecutionEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmRunExecutionEdges):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPipelineStepSpecEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipeline_spec': 'OrmPipelineSpec',
        'run_spec': 'OrmRunSpec',
        'step_executions': 'list[OrmPipelineStepExecution]'
    }

    attribute_map = {
        'pipeline_spec': 'pipeline_spec',
        'run_spec': 'run_spec',
        'step_executions': 'step_executions'
    }

    def __init__(self, pipeline_spec=None, run_spec=None, step_executions=None, local_vars_configuration=None):  # noqa: E501
        """OrmPipelineStepSpecEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._pipeline_spec = None
        self._run_spec = None
        self._step_executions = None
        self.discriminator = None

        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if run_spec is not None:
            self.run_spec = run_spec
        if step_executions is not None:
            self.step_executions = step_executions

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: OrmPipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this OrmPipelineStepSpecEdges.


        :param pipeline_spec: The pipeline_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type pipeline_spec: OrmPipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def run_spec(self):
        """Gets the run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: OrmRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this OrmPipelineStepSpecEdges.


        :param run_spec: The run_spec of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type run_spec: OrmRunSpec
        """

        self._run_spec = run_spec

    @property
    def step_executions(self):
        """Gets the step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501


        :return: The step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501
        :rtype: list[OrmPipelineStepExecution]
        """
        return self._step_executions

    @step_executions.setter
    def step_executions(self, step_executions):
        """Sets the step_executions of this OrmPipelineStepSpecEdges.


        :param step_executions: The step_executions of this OrmPipelineStepSpecEdges.  # noqa: E501
        :type step_executions: list[OrmPipelineStepExecution]
        """

        self._step_executions = step_executions

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPipelineStepSpecEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPipelineStepSpecEdges):
            return True

        return self.to_dict() != other.to_dict()
